﻿using System;

namespace KellermanSoftware.NetSFtpLibraryCoreDemo
{
    class Program
    {
        static void Main(string[] args)
        {
            var parser = new CommandLineParser(CreateConfigurationFile, Upload, Download);
            try
            {
                parser.Parse(args);
            }
            catch (Exception exception)
            {
                Console.WriteLine(exception.Message);
            }
        }

        private static void CreateConfigurationFile(string filePath, Configuration configuration)
        {
            var encryptor = new Encryptor();
            encryptor.Encrypt(configuration);

            var serializer = new ConfigurationSerializer();
            serializer.Serialize(configuration, filePath);

            Console.WriteLine("Configuration has been successfully saved into {0} file", filePath);
        }

        private static void Upload(string configurationFilePath, string source, string destination)
        {
            var serializer = new ConfigurationSerializer();
            var configuration = serializer.Deserialize(configurationFilePath);

            var encryptor = new Encryptor();
            encryptor.Decrypt(configuration);

            using (var sftpClient = new SftpClient(configuration))
            {
                sftpClient.Upload(source, destination);
            }

            Console.WriteLine("{0} has been uploaded successfully", source);
        }

        private static void Download(string configurationFilePath, string source, string destination)
        {
            var serializer = new ConfigurationSerializer();
            var configuration = serializer.Deserialize(configurationFilePath);

            var encryptor = new Encryptor();
            encryptor.Decrypt(configuration);

            using (var sftpClient = new SftpClient(configuration))
            {
                sftpClient.Download(source, destination);
            }

            Console.WriteLine("{0} has been downloaded successfully", source);
        }
    }
}