using System;
using System.Windows.Forms;
using System.Threading;
using System.IO;
using KellermanSoftware.NetSFtpLibrary;

namespace KellermanSoftware.NetSftpLibraryDemo
{
    
    delegate void ProgressEvent(object sender, TransferProgressChangedEventArgs e);
    delegate void CompleteEvent(object sender, TransferCompletedEventArgs e);

    public partial class ProgressForm : Form
    {
        public SFTP Sftp;
        public bool IsDownloading;
        private bool _cancelled = true;
        private string _curFile;
        private bool _closing = false;

        public ProgressForm()
        {
            InitializeComponent();
        }

        /// <summary>
        /// Fired when the transfer completes, it closes the form
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        public void FtpTransferCompleteEvent(object sender, TransferCompletedEventArgs e)
        {
            try
            {
                if (InvokeRequired)
                {
                    CompleteEvent prog = FtpTransferCompleteEvent;
                    Invoke(prog, new [] { sender, e });
                    return;
                }
                _cancelled = false;
                Close();
            }
            catch
            {
            }
        }

        /// <summary>
        /// Updates the GUI during an async transfer
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        public void FtpProgressEvent(object sender, TransferProgressChangedEventArgs e)
        {
            if (Disposing || _closing)
            {
                return;
            }

            if (InvokeRequired)
            {
                ProgressEvent prog = FtpProgressEvent;
                Invoke(prog, new [] { sender, e });
                return;
            }

            _curFile = Sftp.CurrentFileBeingTransferred;
            if (IsDownloading)
                _curFile = Sftp.CurrentFileBeingTransferredDestination + Path.DirectorySeparatorChar + _curFile;

            groupBox1.Text = "Transfering: " + _curFile;
            if (e.TotalBytesToTransfer > 0)
            {
                progressBar.Value = e.ProgressPercentage;
                lblTimeRemaining.Text = Sftp.EstimatedTimeRemaining.ToString();
                lblRemaining.Text = (e.TotalBytesToTransfer - e.BytesTransferred).ToString();
            }

            lblAvg.Text = Sftp.KiloByteAverage.ToString("n" + 2);
            lblCurrent.Text = Sftp.KiloBytePerSecond.ToString("n" + 2);
            lblElapsed.Text = Sftp.TimeElapsed.ToString();
            lblPeak.Text = Sftp.KiloBytePeak.ToString("n" + 2);
            lblTransfered.Text = e.BytesTransferred.ToString();
            lblIsBusy.Text = Sftp.IsBusy.ToString();
        }

        /// <summary>
        /// Fired when the form is closing, it cancels the async trasnfer
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        void Form2_FormClosing(object sender, FormClosingEventArgs e)
        {
            _closing = true;
            if (_cancelled)
            {
                Sftp.Cancel();
                try
                {
                    if (IsDownloading)
                    {
                        Thread.Sleep(500);
                    }
                }
                catch (Exception)
                {
                }
            }
        }

        /// <summary>
        /// Closes the form and cancels the async transfer
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void btnClose_Click(object sender, EventArgs e)
        {
            Close();
        }
    }
}